# 1.3.0

- Added `template` command for managing user templates.
- Added command aliases.
- Help message no longer shows Typer completion options.
- Tweaked command help descriptions.

# 1.2.2

- Added RSS feed generation.
- Added default post description to configuration.
- Added time-of-day support to post `date` frontmatter parsing.
- `zona init` now only writes `footer.md` to the templates directory.

# 1.2.1

- Added `--version` flag to CLI.

# 1.2.0

- Improved the appearance and semantics of post navigation buttons.
  - Navigation now follows "newer/older" logic.
- Added hover symbols to page titles.
- Improved the styling of hover symbols and links.

# 1.1.0

- Major improvements to default stylesheet.
- Frontmatter option to ignore file.
- Improvements to title and date rendering in templates.
- Added smooth scrolling to default stylesheet.
- Fixed a crash when user templates directory was missing when starting the
  server.
- Added "next/previous" navigation buttons to posts.
- User template directory is now merged with defaults instead of it being one or
  the other.

# 1.0.0

Initial release!
